@@ -8,5 +8,5 @@ DeclarativeBase = declarative_base()
 def init_model(app_session):
     DBSession.configure(app_session)
 
-from models import Comment
+from models import Comment, CommentVote
 
